@@ -370,6 +370,11 @@ class jsonrpc_method(object):
     If ``method`` is not supplied, then the callable name will be used
     for the method name.
 
+    ``_depth`` may be specified when wrapping ``jsonrpc_method`` in another
+    decorator. The value should reflect how many stack frames are between
+    the wrapped target and ``jsonrpc_method``. Thus a decorator one level deep
+    would pass in ``_depth=1``.
+
     This is the lazy analog to the
     :func:`~pyramid_rpc.jsonrpc.add_jsonrpc_method`` and accepts all of
     the same arguments.
@@ -382,12 +387,14 @@ class jsonrpc_method(object):
     def __call__(self, wrapped):
         kw = self.kw.copy()
         kw['method'] = self.method or wrapped.__name__
+        depth = kw.pop('_depth', 0)
 
         def callback(context, name, ob):
             config = context.config.with_package(info.module)
             config.add_jsonrpc_method(view=ob, **kw)
 
-        info = venusian.attach(wrapped, callback, category='pyramid')
+        info = venusian.attach(wrapped, callback, category='pyramid',
+                               depth=depth + 1)
         if info.scope == 'class':
             # ensure that attr is set if decorating a class method
             kw.setdefault('attr', wrapped.__name__)
